@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
-# Copyright (c) 2020-2021 Julian Heinovski <heinovski@ccs-labs.org>
+# Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -47,10 +47,11 @@ def parse_args() -> (argparse.Namespace, argparse._ArgumentGroup):
     parser = argparse.ArgumentParser(
         formatter_class=CustomFormatter,
         allow_abbrev=False,
-        description=textwrap.dedent("""
-            Platoon Formation Simulator (PlaFoSim) -- A simple and scalable simulator for platoon formation.
+        description=textwrap.dedent(f"""
+            Platoon Formation Simulator (PlaFoSim) -- Version {__version__}.
+            A simple and scalable simulator for platoon formation.
 
-            Copyright (c) 2020-2021 Julian Heinovski <heinovski@ccs-labs.org>
+            Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
             This program comes with ABSOLUTELY NO WARRANTY.
             This is free software, and you are welcome to redistribute it under certain conditions.
 
@@ -87,6 +88,11 @@ def parse_args() -> (argparse.Namespace, argparse._ArgumentGroup):
         action="version",
         version=f"%(prog)s {__version__}",
     )
+    parser.add_argument(
+        "-d", "--default",
+        action="store_true",
+        help="run a simulation with the default configuration and exit",
+    )
     parser.add_argument(
         "-n", "--dry-run",
         action="store_true",
@@ -342,8 +348,8 @@ def parse_args() -> (argparse.Namespace, argparse._ArgumentGroup):
         "--formation-algorithm",
         type=str,
         default=DEFAULTS['formation_algorithm'],
-        choices=["speedposition"],
         # TODO use enum
+        choices=[SpeedPosition.__name__],
         help="The formation algorithm to use",
     )
     formation.add_argument(
@@ -360,7 +366,8 @@ def parse_args() -> (argparse.Namespace, argparse._ArgumentGroup):
         help="The interval between two iterations of a formation algorithm in s",
     )
 
-    # formation algorithm speed position properties
+    # formation algorithm specific properties
+    ## speed position
     SpeedPosition.add_parser_argument_group(parser)
 
     # infrastructure properties
@@ -612,6 +619,12 @@ def parse_args() -> (argparse.Namespace, argparse._ArgumentGroup):
         help="Whether to record results for pre-filled vehicles",
     )
 
+    # print usage without any arguments
+    if len(sys.argv) < 2:
+        # no argument has been passed
+        print(parser.format_usage(), parser.description, end='')
+        sys.exit(0)
+
     args = parser.parse_args()
 
     # transform argument values into correct units
@@ -663,6 +676,9 @@ def main():
     # get argument values (and gui argument group)
     args, gui = parse_args()
 
+    if args.default:
+        print("Running with default configuration...")
+
     if args.dry_run:
         print(f"Current configuration:\n{dict(sorted(vars(args).items()))}")
         return
